
# Type: variant to disease association_object




URI: [biolink:variant_to_disease_association_object](https://w3id.org/biolink/vocab/variant_to_disease_association_object)


## Domain and Range

[VariantToDiseaseAssociation](VariantToDiseaseAssociation.md) ->  <sub>REQ</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [VariantToDiseaseAssociation](VariantToDiseaseAssociation.md)
